package com.persagy.framework.apilog.serializer;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;

/**
 * 基于 Jackson 的序列化器，仅在类路径中有 jackson 并且没有注册其他的 json 序列化器时使用
 */
@Slf4j
@ConditionalOnClass(name = "com.fasterxml.jackson.databind.ObjectMapper")
@ConditionalOnMissingBean(JacksonJsonSerializer.class)
public class JacksonJsonSerializer implements JsonSerializer {
    private static final ObjectMapper JACKSON_MAPPER = new ObjectMapper();

    @Override
    public String serialize(Object object) {
        if (object == null) {
            return "";
        }
        try {
            return JACKSON_MAPPER.writeValueAsString(object);
        } catch (JsonProcessingException e) {
            log.warn("对象序列化失败: {}", object);
        }
        return "";
    }

}
